import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy, Input, ViewChild, NgModule } from '@angular/core';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';

const VIEWBOX_WIDTH$1 = 100;
const VIEWBOX_HEIGHT$1 = 100;
const VIEWBOX_HEIGHT_HALF$1 = 50;
const VIEWBOX_CENTER_X$1 = 50;
const VIEWBOX_CENTER_Y$1 = 50;

const VIEWBOX_WIDTH = 100;
const VIEWBOX_HEIGHT = 100;
const VIEWBOX_HEIGHT_HALF = 50;
const VIEWBOX_CENTER_X = 50;
const VIEWBOX_CENTER_Y = 50;
function getPathDescription({ pathRadius, counterClockwise, }) {
    const radius = pathRadius;
    const rotation = counterClockwise ? 1 : 0;
    // Move to center of canvas
    // Relative move to top canvas
    // Relative arc to bottom of canvas
    // Relative arc to top of canvas
    return `
      M ${VIEWBOX_CENTER_X},${VIEWBOX_CENTER_Y}
      m 0,-${radius}
      a ${radius},${radius} ${rotation} 1 1 0,${2 * radius}
      a ${radius},${radius} ${rotation} 1 1 0,-${2 * radius}
    `;
}
function getDashStyle({ counterClockwise, dashRatio, pathRadius, }) {
    const diameter = Math.PI * 2 * pathRadius;
    const gapLength = (1 - dashRatio) * diameter;
    return {
        // Have dash be full diameter, and gap be full diameter
        strokeDasharray: `${diameter}px ${diameter}px`,
        // Shift dash backward by gapLength, so gap starts appearing at correct distance
        strokeDashoffset: `${counterClockwise ? -gapLength : gapLength}px`,
    };
}
class PathComponent {
    ngOnChanges(changes) {
        const pathRadius = this.pathRadius;
        const dashRatio = this.dashRatio;
        const counterClockwise = this.counterClockwise;
        this.d = getPathDescription({ pathRadius, counterClockwise });
        this.updatedStyle = Object.assign({}, this.styles, getDashStyle({ pathRadius, dashRatio, counterClockwise }));
    }
}
PathComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: PathComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
PathComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: PathComponent, selector: "[doge-path]", inputs: { className: "className", counterClockwise: "counterClockwise", dashRatio: "dashRatio", pathRadius: "pathRadius", strokeWidth: "strokeWidth", styles: "styles" }, usesOnChanges: true, ngImport: i0, template: "<svg:path [ngClass]=\"className\" [ngStyle]=\"updatedStyle\" [attr.d]=\"d\" [attr.stroke-width]=\"strokeWidth\"\n  [attr.fill-opacity]=\"0\" />\n", directives: [{ type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i2.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: PathComponent, decorators: [{
            type: Component,
            args: [{ selector: '[doge-path]', changeDetection: ChangeDetectionStrategy.OnPush, template: "<svg:path [ngClass]=\"className\" [ngStyle]=\"updatedStyle\" [attr.d]=\"d\" [attr.stroke-width]=\"strokeWidth\"\n  [attr.fill-opacity]=\"0\" />\n" }]
        }], propDecorators: { className: [{
                type: Input
            }], counterClockwise: [{
                type: Input
            }], dashRatio: [{
                type: Input
            }], pathRadius: [{
                type: Input
            }], strokeWidth: [{
                type: Input
            }], styles: [{
                type: Input
            }] } });

class NgCircularProgressbarComponent {
    constructor() {
        this.background = false;
        this.backgroundPadding = 0;
        this.circleRatio = 1;
        this.classes = {
            root: 'CircularProgressbar',
            trail: 'CircularProgressbar-trail',
            path: 'CircularProgressbar-path',
            text: 'CircularProgressbar-text',
            background: 'CircularProgressbar-background',
        };
        this.counterClockwise = false;
        this.className = '';
        this.maxValue = 100;
        this.minValue = 0;
        this.strokeWidth = 8;
        this.styles = {
            root: {},
            trail: {},
            path: {},
            text: {},
            background: {},
        };
        this.text = '';
    }
    ngOnChanges(changes) {
        this.pathRadius = this.getPathRadius();
        this.pathRatio = this.getPathRatio();
    }
    get VIEWBOX() {
        return `0 0 ${VIEWBOX_WIDTH$1} ${VIEWBOX_HEIGHT$1}`;
    }
    get VIEWBOX_CENTER_X() {
        return VIEWBOX_CENTER_X$1;
    }
    get VIEWBOX_CENTER_Y() {
        return VIEWBOX_CENTER_Y$1;
    }
    get VIEWBOX_HEIGHT_HALF() {
        return VIEWBOX_HEIGHT_HALF$1;
    }
    getBackgroundPadding() {
        if (!this.background) {
            // Don't add padding if not displaying background
            return 0;
        }
        return this.backgroundPadding;
    }
    getPathRadius() {
        // The radius of the path is defined to be in the middle, so in order for the path to
        // fit perfectly inside the 100x100 viewBox, need to subtract half the strokeWidth
        return VIEWBOX_HEIGHT_HALF$1 - this.strokeWidth / 2 - this.getBackgroundPadding();
    }
    // Ratio of path length to trail length, as a value between 0 and 1
    getPathRatio() {
        const boundedValue = Math.min(Math.max(this.value, this.minValue), this.maxValue);
        return (boundedValue - this.minValue) / (this.maxValue - this.minValue);
    }
}
NgCircularProgressbarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NgCircularProgressbarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
NgCircularProgressbarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NgCircularProgressbarComponent, selector: "ng-circular-progressbar", inputs: { value: "value", background: "background", backgroundPadding: "backgroundPadding", circleRatio: "circleRatio", classes: "classes", counterClockwise: "counterClockwise", className: "className", maxValue: "maxValue", minValue: "minValue", strokeWidth: "strokeWidth", styles: "styles", text: "text" }, usesOnChanges: true, ngImport: i0, template: "<svg [ngClass]=\"[classes.root, className]\" [ngStyle]=\"styles.root\" [attr.viewBox]=\"VIEWBOX\">\n  <circle *ngIf=\"background\" [ngClass]=\"classes.background\" [ngStyle]=\"styles.background\" [attr.cx]=\"VIEWBOX_CENTER_X\"\n    [attr.cy]=\"VIEWBOX_CENTER_Y\" [attr.r]=\"VIEWBOX_HEIGHT_HALF\" />\n\n  <g doge-path [className]=\"classes.trail\" [styles]=\"styles.trail\" [counterClockwise]=\"counterClockwise\"\n    [dashRatio]=\"circleRatio\" [pathRadius]=\"pathRadius\" [strokeWidth]=\"strokeWidth\" />\n  <g doge-path [className]=\"classes.path\" [styles]=\"styles.path\" [counterClockwise]=\"counterClockwise\"\n    [dashRatio]=\"pathRatio * circleRatio\" [pathRadius]=\"pathRadius\" [strokeWidth]=\"strokeWidth\" />\n\n  <text *ngIf=\"text\" [ngClass]=\"classes.text\" [ngStyle]=\"styles.text\" [attr.x]=\"VIEWBOX_CENTER_X\"\n    [attr.y]=\"VIEWBOX_CENTER_Y\">\n    {{text}}\n  </text>\n</svg>\n", styles: [":host{display:contents}::ng-deep .CircularProgressbar{width:100%;vertical-align:middle}::ng-deep .CircularProgressbar .CircularProgressbar-path{stroke:#3e98c7;stroke-linecap:round;transition:stroke-dashoffset .5s ease 0s}::ng-deep .CircularProgressbar .CircularProgressbar-trail{stroke:#d6d6d6;stroke-linecap:round}::ng-deep .CircularProgressbar .CircularProgressbar-text{fill:#3e98c7;font-size:20px;dominant-baseline:middle;text-anchor:middle}::ng-deep .CircularProgressbar .CircularProgressbar-background{fill:#d6d6d6}::ng-deep .CircularProgressbar.CircularProgressbar-inverted .CircularProgressbar-background{fill:#3e98c7}::ng-deep .CircularProgressbar.CircularProgressbar-inverted .CircularProgressbar-text{fill:#fff}::ng-deep .CircularProgressbar.CircularProgressbar-inverted .CircularProgressbar-path{stroke:#fff}::ng-deep .CircularProgressbar.CircularProgressbar-inverted .CircularProgressbar-trail{stroke:transparent}\n"], components: [{ type: PathComponent, selector: "[doge-path]", inputs: ["className", "counterClockwise", "dashRatio", "pathRadius", "strokeWidth", "styles"] }], directives: [{ type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i2.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NgCircularProgressbarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ng-circular-progressbar', changeDetection: ChangeDetectionStrategy.OnPush, template: "<svg [ngClass]=\"[classes.root, className]\" [ngStyle]=\"styles.root\" [attr.viewBox]=\"VIEWBOX\">\n  <circle *ngIf=\"background\" [ngClass]=\"classes.background\" [ngStyle]=\"styles.background\" [attr.cx]=\"VIEWBOX_CENTER_X\"\n    [attr.cy]=\"VIEWBOX_CENTER_Y\" [attr.r]=\"VIEWBOX_HEIGHT_HALF\" />\n\n  <g doge-path [className]=\"classes.trail\" [styles]=\"styles.trail\" [counterClockwise]=\"counterClockwise\"\n    [dashRatio]=\"circleRatio\" [pathRadius]=\"pathRadius\" [strokeWidth]=\"strokeWidth\" />\n  <g doge-path [className]=\"classes.path\" [styles]=\"styles.path\" [counterClockwise]=\"counterClockwise\"\n    [dashRatio]=\"pathRatio * circleRatio\" [pathRadius]=\"pathRadius\" [strokeWidth]=\"strokeWidth\" />\n\n  <text *ngIf=\"text\" [ngClass]=\"classes.text\" [ngStyle]=\"styles.text\" [attr.x]=\"VIEWBOX_CENTER_X\"\n    [attr.y]=\"VIEWBOX_CENTER_Y\">\n    {{text}}\n  </text>\n</svg>\n", styles: [":host{display:contents}::ng-deep .CircularProgressbar{width:100%;vertical-align:middle}::ng-deep .CircularProgressbar .CircularProgressbar-path{stroke:#3e98c7;stroke-linecap:round;transition:stroke-dashoffset .5s ease 0s}::ng-deep .CircularProgressbar .CircularProgressbar-trail{stroke:#d6d6d6;stroke-linecap:round}::ng-deep .CircularProgressbar .CircularProgressbar-text{fill:#3e98c7;font-size:20px;dominant-baseline:middle;text-anchor:middle}::ng-deep .CircularProgressbar .CircularProgressbar-background{fill:#d6d6d6}::ng-deep .CircularProgressbar.CircularProgressbar-inverted .CircularProgressbar-background{fill:#3e98c7}::ng-deep .CircularProgressbar.CircularProgressbar-inverted .CircularProgressbar-text{fill:#fff}::ng-deep .CircularProgressbar.CircularProgressbar-inverted .CircularProgressbar-path{stroke:#fff}::ng-deep .CircularProgressbar.CircularProgressbar-inverted .CircularProgressbar-trail{stroke:transparent}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { value: [{
                type: Input
            }], background: [{
                type: Input
            }], backgroundPadding: [{
                type: Input
            }], circleRatio: [{
                type: Input
            }], classes: [{
                type: Input
            }], counterClockwise: [{
                type: Input
            }], className: [{
                type: Input
            }], maxValue: [{
                type: Input
            }], minValue: [{
                type: Input
            }], strokeWidth: [{
                type: Input
            }], styles: [{
                type: Input
            }], text: [{
                type: Input
            }] } });

class CircularProgressbarWithChildrenComponent {
    constructor() {
        this.background = false;
        this.backgroundPadding = 0;
        this.circleRatio = 1;
        this.classes = {
            root: 'CircularProgressbar',
            trail: 'CircularProgressbar-trail',
            path: 'CircularProgressbar-path',
            text: 'CircularProgressbar-text',
            background: 'CircularProgressbar-background',
        };
        this.counterClockwise = false;
        this.className = '';
        this.maxValue = 100;
        this.minValue = 0;
        this.strokeWidth = 8;
        this.styles = {
            root: {},
            trail: {},
            path: {},
            text: {},
            background: {},
        };
        this.text = '';
    }
}
CircularProgressbarWithChildrenComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: CircularProgressbarWithChildrenComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
CircularProgressbarWithChildrenComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: CircularProgressbarWithChildrenComponent, selector: "ng-circular-progressbar-with-children", inputs: { value: "value", background: "background", backgroundPadding: "backgroundPadding", circleRatio: "circleRatio", classes: "classes", counterClockwise: "counterClockwise", className: "className", maxValue: "maxValue", minValue: "minValue", strokeWidth: "strokeWidth", styles: "styles", text: "text" }, viewQueries: [{ propertyName: "child", first: true, predicate: ["child"], descendants: true }], ngImport: i0, template: "<div data-test-id=\"CircularProgressbarWithChildren\">\n  <!-- Has an extra div wrapper because otherwise, adding content after this progressbar is spaced weirdly. -->\n  <div style=\"position: relative; width: 100%; height: 100%\">\n    <!-- Progressbar is not positioned absolutely, so that it can establish intrinsic size for props.children's content. -->\n    <ng-circular-progressbar [value]=\"value\" [background]=\"background\" [backgroundPadding]=\"backgroundPadding\"\n      [circleRatio]=\"circleRatio\" [classes]=\"classes\" [counterClockwise]=\"counterClockwise\" [className]=\"className\"\n      [maxValue]=\"maxValue\" [minValue]=\"minValue\" [styles]=\"styles\" [text]=\"text\"></ng-circular-progressbar>\n\n    <!-- Children are positioned absolutely, and height adapts to the progressbar's intrinsic size. It appears below the progressbar, but negative margin moves it back up. -->\n    <div class=\"child-circle\">\n      <ng-content #child>\n      </ng-content>\n    </div>\n\n  </div>\n</div>\n", styles: [".child-circle{position:absolute;width:100%;height:100%;margin-top:-100%;display:flex;flex-direction:column;justify-content:center;align-items:center}\n"], components: [{ type: NgCircularProgressbarComponent, selector: "ng-circular-progressbar", inputs: ["value", "background", "backgroundPadding", "circleRatio", "classes", "counterClockwise", "className", "maxValue", "minValue", "strokeWidth", "styles", "text"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: CircularProgressbarWithChildrenComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ng-circular-progressbar-with-children', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div data-test-id=\"CircularProgressbarWithChildren\">\n  <!-- Has an extra div wrapper because otherwise, adding content after this progressbar is spaced weirdly. -->\n  <div style=\"position: relative; width: 100%; height: 100%\">\n    <!-- Progressbar is not positioned absolutely, so that it can establish intrinsic size for props.children's content. -->\n    <ng-circular-progressbar [value]=\"value\" [background]=\"background\" [backgroundPadding]=\"backgroundPadding\"\n      [circleRatio]=\"circleRatio\" [classes]=\"classes\" [counterClockwise]=\"counterClockwise\" [className]=\"className\"\n      [maxValue]=\"maxValue\" [minValue]=\"minValue\" [styles]=\"styles\" [text]=\"text\"></ng-circular-progressbar>\n\n    <!-- Children are positioned absolutely, and height adapts to the progressbar's intrinsic size. It appears below the progressbar, but negative margin moves it back up. -->\n    <div class=\"child-circle\">\n      <ng-content #child>\n      </ng-content>\n    </div>\n\n  </div>\n</div>\n", styles: [".child-circle{position:absolute;width:100%;height:100%;margin-top:-100%;display:flex;flex-direction:column;justify-content:center;align-items:center}\n"] }]
        }], propDecorators: { child: [{
                type: ViewChild,
                args: ['child']
            }], value: [{
                type: Input
            }], background: [{
                type: Input
            }], backgroundPadding: [{
                type: Input
            }], circleRatio: [{
                type: Input
            }], classes: [{
                type: Input
            }], counterClockwise: [{
                type: Input
            }], className: [{
                type: Input
            }], maxValue: [{
                type: Input
            }], minValue: [{
                type: Input
            }], strokeWidth: [{
                type: Input
            }], styles: [{
                type: Input
            }], text: [{
                type: Input
            }] } });

class NgCircularProgressbarModule {
}
NgCircularProgressbarModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NgCircularProgressbarModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgCircularProgressbarModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NgCircularProgressbarModule, declarations: [NgCircularProgressbarComponent,
        CircularProgressbarWithChildrenComponent,
        PathComponent], imports: [CommonModule], exports: [NgCircularProgressbarComponent,
        CircularProgressbarWithChildrenComponent] });
NgCircularProgressbarModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NgCircularProgressbarModule, imports: [[
            CommonModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NgCircularProgressbarModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        NgCircularProgressbarComponent,
                        CircularProgressbarWithChildrenComponent,
                        PathComponent
                    ],
                    imports: [
                        CommonModule
                    ],
                    exports: [
                        NgCircularProgressbarComponent,
                        CircularProgressbarWithChildrenComponent
                    ]
                }]
        }] });

function buildStyles({ rotation, strokeLinecap, textColor, textSize, pathColor, pathTransition, pathTransitionDuration, trailColor, backgroundColor, }) {
    const rotationTransform = rotation == null ? undefined : `rotate(${rotation}turn)`;
    const rotationTransformOrigin = rotation == null ? undefined : 'center center';
    return {
        root: {},
        path: removeUndefinedValues({
            stroke: pathColor,
            strokeLinecap: strokeLinecap,
            transform: rotationTransform,
            transformOrigin: rotationTransformOrigin,
            transition: pathTransition,
            transitionDuration: pathTransitionDuration == null ? undefined : `${pathTransitionDuration}s`,
        }),
        trail: removeUndefinedValues({
            stroke: trailColor,
            strokeLinecap: strokeLinecap,
            transform: rotationTransform,
            transformOrigin: rotationTransformOrigin,
        }),
        text: removeUndefinedValues({
            fill: textColor,
            fontSize: textSize,
        }),
        background: removeUndefinedValues({
            fill: backgroundColor,
        }),
    };
}
function removeUndefinedValues(obj) {
    Object.keys(obj).forEach((key) => {
        if (obj[key] == null) {
            delete obj[key];
        }
    });
    return obj;
}

/*
 * Public API Surface of ng-circular-progressbar
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CircularProgressbarWithChildrenComponent, NgCircularProgressbarComponent, NgCircularProgressbarModule, buildStyles };
//# sourceMappingURL=plcoder-ng-circular-progressbar-dev.mjs.map
